@@ -17,6 +17,9 @@ class HTTPLocation(BaseFileLocation):
         """Resolve patterns in path"""
         return [self.path]
 
+    def validate_conn(self):
+        """Override as conn_id is not always required for http location."""
+
     @property
     def size(self) -> int:
         """Return file size for HTTP location"""
